==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/InfoItemSourceFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class InfoItemSourceFluentImpl<A extends InfoItemSourceFluent<A>> extends BaseFluent<A> implements InfoItemSourceFluent<A>{
  public InfoItemSourceFluentImpl() {
  }
  public InfoItemSourceFluentImpl(InfoItemSource instance) {
    this.withConfigMapKeyRef(instance.getConfigMapKeyRef()); 
    this.withIngressRef(instance.getIngressRef()); 
    this.withSecretKeyRef(instance.getSecretKeyRef()); 
    this.withServiceRef(instance.getServiceRef()); 
    this.withType(instance.getType()); 
  }
  private ConfigMapKeySelectorBuilder configMapKeyRef;
  private IngressSelectorBuilder ingressRef;
  private SecretKeySelectorBuilder secretKeyRef;
  private ServiceSelectorBuilder serviceRef;
  private String type;
  
  /**
   * This method has been deprecated, please use method buildConfigMapKeyRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapKeySelector getConfigMapKeyRef() {
    return this.configMapKeyRef!=null ?this.configMapKeyRef.build():null;
  }
  public ConfigMapKeySelector buildConfigMapKeyRef() {
    return this.configMapKeyRef!=null ?this.configMapKeyRef.build():null;
  }
  public A withConfigMapKeyRef(ConfigMapKeySelector configMapKeyRef) {
    _visitables.get("configMapKeyRef").remove(this.configMapKeyRef);
    if (configMapKeyRef!=null){ this.configMapKeyRef= new ConfigMapKeySelectorBuilder(configMapKeyRef); _visitables.get("configMapKeyRef").add(this.configMapKeyRef);} else { this.configMapKeyRef = null; _visitables.get("configMapKeyRef").remove(this.configMapKeyRef); } return (A) this;
  }
  public Boolean hasConfigMapKeyRef() {
    return this.configMapKeyRef != null;
  }
  public InfoItemSourceFluent.ConfigMapKeyRefNested<A> withNewConfigMapKeyRef() {
    return new InfoItemSourceFluentImpl.ConfigMapKeyRefNestedImpl();
  }
  public InfoItemSourceFluent.ConfigMapKeyRefNested<A> withNewConfigMapKeyRefLike(ConfigMapKeySelector item) {
    return new InfoItemSourceFluentImpl.ConfigMapKeyRefNestedImpl(item);
  }
  public InfoItemSourceFluent.ConfigMapKeyRefNested<A> editConfigMapKeyRef() {
    return withNewConfigMapKeyRefLike(getConfigMapKeyRef());
  }
  public InfoItemSourceFluent.ConfigMapKeyRefNested<A> editOrNewConfigMapKeyRef() {
    return withNewConfigMapKeyRefLike(getConfigMapKeyRef() != null ? getConfigMapKeyRef(): new ConfigMapKeySelectorBuilder().build());
  }
  public InfoItemSourceFluent.ConfigMapKeyRefNested<A> editOrNewConfigMapKeyRefLike(ConfigMapKeySelector item) {
    return withNewConfigMapKeyRefLike(getConfigMapKeyRef() != null ? getConfigMapKeyRef(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIngressRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressSelector getIngressRef() {
    return this.ingressRef!=null ?this.ingressRef.build():null;
  }
  public IngressSelector buildIngressRef() {
    return this.ingressRef!=null ?this.ingressRef.build():null;
  }
  public A withIngressRef(IngressSelector ingressRef) {
    _visitables.get("ingressRef").remove(this.ingressRef);
    if (ingressRef!=null){ this.ingressRef= new IngressSelectorBuilder(ingressRef); _visitables.get("ingressRef").add(this.ingressRef);} else { this.ingressRef = null; _visitables.get("ingressRef").remove(this.ingressRef); } return (A) this;
  }
  public Boolean hasIngressRef() {
    return this.ingressRef != null;
  }
  public InfoItemSourceFluent.IngressRefNested<A> withNewIngressRef() {
    return new InfoItemSourceFluentImpl.IngressRefNestedImpl();
  }
  public InfoItemSourceFluent.IngressRefNested<A> withNewIngressRefLike(IngressSelector item) {
    return new InfoItemSourceFluentImpl.IngressRefNestedImpl(item);
  }
  public InfoItemSourceFluent.IngressRefNested<A> editIngressRef() {
    return withNewIngressRefLike(getIngressRef());
  }
  public InfoItemSourceFluent.IngressRefNested<A> editOrNewIngressRef() {
    return withNewIngressRefLike(getIngressRef() != null ? getIngressRef(): new IngressSelectorBuilder().build());
  }
  public InfoItemSourceFluent.IngressRefNested<A> editOrNewIngressRefLike(IngressSelector item) {
    return withNewIngressRefLike(getIngressRef() != null ? getIngressRef(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSecretKeyRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeySelector getSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  public SecretKeySelector buildSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  public A withSecretKeyRef(SecretKeySelector secretKeyRef) {
    _visitables.get("secretKeyRef").remove(this.secretKeyRef);
    if (secretKeyRef!=null){ this.secretKeyRef= new SecretKeySelectorBuilder(secretKeyRef); _visitables.get("secretKeyRef").add(this.secretKeyRef);} else { this.secretKeyRef = null; _visitables.get("secretKeyRef").remove(this.secretKeyRef); } return (A) this;
  }
  public Boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  public InfoItemSourceFluent.SecretKeyRefNested<A> withNewSecretKeyRef() {
    return new InfoItemSourceFluentImpl.SecretKeyRefNestedImpl();
  }
  public InfoItemSourceFluent.SecretKeyRefNested<A> withNewSecretKeyRefLike(SecretKeySelector item) {
    return new InfoItemSourceFluentImpl.SecretKeyRefNestedImpl(item);
  }
  public InfoItemSourceFluent.SecretKeyRefNested<A> editSecretKeyRef() {
    return withNewSecretKeyRefLike(getSecretKeyRef());
  }
  public InfoItemSourceFluent.SecretKeyRefNested<A> editOrNewSecretKeyRef() {
    return withNewSecretKeyRefLike(getSecretKeyRef() != null ? getSecretKeyRef(): new SecretKeySelectorBuilder().build());
  }
  public InfoItemSourceFluent.SecretKeyRefNested<A> editOrNewSecretKeyRefLike(SecretKeySelector item) {
    return withNewSecretKeyRefLike(getSecretKeyRef() != null ? getSecretKeyRef(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildServiceRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceSelector getServiceRef() {
    return this.serviceRef!=null ?this.serviceRef.build():null;
  }
  public ServiceSelector buildServiceRef() {
    return this.serviceRef!=null ?this.serviceRef.build():null;
  }
  public A withServiceRef(ServiceSelector serviceRef) {
    _visitables.get("serviceRef").remove(this.serviceRef);
    if (serviceRef!=null){ this.serviceRef= new ServiceSelectorBuilder(serviceRef); _visitables.get("serviceRef").add(this.serviceRef);} else { this.serviceRef = null; _visitables.get("serviceRef").remove(this.serviceRef); } return (A) this;
  }
  public Boolean hasServiceRef() {
    return this.serviceRef != null;
  }
  public InfoItemSourceFluent.ServiceRefNested<A> withNewServiceRef() {
    return new InfoItemSourceFluentImpl.ServiceRefNestedImpl();
  }
  public InfoItemSourceFluent.ServiceRefNested<A> withNewServiceRefLike(ServiceSelector item) {
    return new InfoItemSourceFluentImpl.ServiceRefNestedImpl(item);
  }
  public InfoItemSourceFluent.ServiceRefNested<A> editServiceRef() {
    return withNewServiceRefLike(getServiceRef());
  }
  public InfoItemSourceFluent.ServiceRefNested<A> editOrNewServiceRef() {
    return withNewServiceRefLike(getServiceRef() != null ? getServiceRef(): new ServiceSelectorBuilder().build());
  }
  public InfoItemSourceFluent.ServiceRefNested<A> editOrNewServiceRefLike(ServiceSelector item) {
    return withNewServiceRefLike(getServiceRef() != null ? getServiceRef(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    InfoItemSourceFluentImpl that = (InfoItemSourceFluentImpl) o;
    if (configMapKeyRef != null ? !configMapKeyRef.equals(that.configMapKeyRef) :that.configMapKeyRef != null) return false;
    if (ingressRef != null ? !ingressRef.equals(that.ingressRef) :that.ingressRef != null) return false;
    if (secretKeyRef != null ? !secretKeyRef.equals(that.secretKeyRef) :that.secretKeyRef != null) return false;
    if (serviceRef != null ? !serviceRef.equals(that.serviceRef) :that.serviceRef != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configMapKeyRef,  ingressRef,  secretKeyRef,  serviceRef,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configMapKeyRef != null) { sb.append("configMapKeyRef:"); sb.append(configMapKeyRef + ","); }
    if (ingressRef != null) { sb.append("ingressRef:"); sb.append(ingressRef + ","); }
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef + ","); }
    if (serviceRef != null) { sb.append("serviceRef:"); sb.append(serviceRef + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  class ConfigMapKeyRefNestedImpl<N> extends ConfigMapKeySelectorFluentImpl<InfoItemSourceFluent.ConfigMapKeyRefNested<N>> implements InfoItemSourceFluent.ConfigMapKeyRefNested<N>,Nested<N>{
    ConfigMapKeyRefNestedImpl(ConfigMapKeySelector item) {
      this.builder = new ConfigMapKeySelectorBuilder(this, item);
    }
    ConfigMapKeyRefNestedImpl() {
      this.builder = new ConfigMapKeySelectorBuilder(this);
    }
    ConfigMapKeySelectorBuilder builder;
    public N and() {
      return (N) InfoItemSourceFluentImpl.this.withConfigMapKeyRef(builder.build());
    }
    public N endConfigMapKeyRef() {
      return and();
    }
    
  }
  class IngressRefNestedImpl<N> extends IngressSelectorFluentImpl<InfoItemSourceFluent.IngressRefNested<N>> implements InfoItemSourceFluent.IngressRefNested<N>,Nested<N>{
    IngressRefNestedImpl(IngressSelector item) {
      this.builder = new IngressSelectorBuilder(this, item);
    }
    IngressRefNestedImpl() {
      this.builder = new IngressSelectorBuilder(this);
    }
    IngressSelectorBuilder builder;
    public N and() {
      return (N) InfoItemSourceFluentImpl.this.withIngressRef(builder.build());
    }
    public N endIngressRef() {
      return and();
    }
    
  }
  class SecretKeyRefNestedImpl<N> extends SecretKeySelectorFluentImpl<InfoItemSourceFluent.SecretKeyRefNested<N>> implements InfoItemSourceFluent.SecretKeyRefNested<N>,Nested<N>{
    SecretKeyRefNestedImpl(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    SecretKeyRefNestedImpl() {
      this.builder = new SecretKeySelectorBuilder(this);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) InfoItemSourceFluentImpl.this.withSecretKeyRef(builder.build());
    }
    public N endSecretKeyRef() {
      return and();
    }
    
  }
  class ServiceRefNestedImpl<N> extends ServiceSelectorFluentImpl<InfoItemSourceFluent.ServiceRefNested<N>> implements InfoItemSourceFluent.ServiceRefNested<N>,Nested<N>{
    ServiceRefNestedImpl(ServiceSelector item) {
      this.builder = new ServiceSelectorBuilder(this, item);
    }
    ServiceRefNestedImpl() {
      this.builder = new ServiceSelectorBuilder(this);
    }
    ServiceSelectorBuilder builder;
    public N and() {
      return (N) InfoItemSourceFluentImpl.this.withServiceRef(builder.build());
    }
    public N endServiceRef() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/InfoItemSourceFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class InfoItemSourceFluentImpl<A extends InfoItemSourceFluent<A>> extends BaseFluent<A> implements InfoItemSourceFluent<A>{
  public InfoItemSourceFluentImpl() {
  }
  public InfoItemSourceFluentImpl(InfoItemSource instance) {
    if (instance != null) {
      this.withConfigMapKeyRef(instance.getConfigMapKeyRef());
      this.withIngressRef(instance.getIngressRef());
      this.withSecretKeyRef(instance.getSecretKeyRef());
      this.withServiceRef(instance.getServiceRef());
      this.withType(instance.getType());
    }
  }
  private ConfigMapKeySelectorBuilder configMapKeyRef;
  private IngressSelectorBuilder ingressRef;
  private SecretKeySelectorBuilder secretKeyRef;
  private ServiceSelectorBuilder serviceRef;
  private String type;
  
  /**
   * This method has been deprecated, please use method buildConfigMapKeyRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapKeySelector getConfigMapKeyRef() {
    return this.configMapKeyRef!=null ?this.configMapKeyRef.build():null;
  }
  public ConfigMapKeySelector buildConfigMapKeyRef() {
    return this.configMapKeyRef!=null ?this.configMapKeyRef.build():null;
  }
  public A withConfigMapKeyRef(ConfigMapKeySelector configMapKeyRef) {
    _visitables.get("configMapKeyRef").remove(this.configMapKeyRef);
    if (configMapKeyRef!=null){ this.configMapKeyRef= new ConfigMapKeySelectorBuilder(configMapKeyRef); _visitables.get("configMapKeyRef").add(this.configMapKeyRef);} else { this.configMapKeyRef = null; _visitables.get("configMapKeyRef").remove(this.configMapKeyRef); } return (A) this;
  }
  public Boolean hasConfigMapKeyRef() {
    return this.configMapKeyRef != null;
  }
  public InfoItemSourceFluentImpl.ConfigMapKeyRefNested<A> withNewConfigMapKeyRef() {
    return new InfoItemSourceFluentImpl.ConfigMapKeyRefNestedImpl();
  }
  public InfoItemSourceFluentImpl.ConfigMapKeyRefNested<A> withNewConfigMapKeyRefLike(ConfigMapKeySelector item) {
    return new InfoItemSourceFluentImpl.ConfigMapKeyRefNestedImpl(item);
  }
  public InfoItemSourceFluentImpl.ConfigMapKeyRefNested<A> editConfigMapKeyRef() {
    return withNewConfigMapKeyRefLike(getConfigMapKeyRef());
  }
  public InfoItemSourceFluentImpl.ConfigMapKeyRefNested<A> editOrNewConfigMapKeyRef() {
    return withNewConfigMapKeyRefLike(getConfigMapKeyRef() != null ? getConfigMapKeyRef(): new ConfigMapKeySelectorBuilder().build());
  }
  public InfoItemSourceFluentImpl.ConfigMapKeyRefNested<A> editOrNewConfigMapKeyRefLike(ConfigMapKeySelector item) {
    return withNewConfigMapKeyRefLike(getConfigMapKeyRef() != null ? getConfigMapKeyRef(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIngressRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressSelector getIngressRef() {
    return this.ingressRef!=null ?this.ingressRef.build():null;
  }
  public IngressSelector buildIngressRef() {
    return this.ingressRef!=null ?this.ingressRef.build():null;
  }
  public A withIngressRef(IngressSelector ingressRef) {
    _visitables.get("ingressRef").remove(this.ingressRef);
    if (ingressRef!=null){ this.ingressRef= new IngressSelectorBuilder(ingressRef); _visitables.get("ingressRef").add(this.ingressRef);} else { this.ingressRef = null; _visitables.get("ingressRef").remove(this.ingressRef); } return (A) this;
  }
  public Boolean hasIngressRef() {
    return this.ingressRef != null;
  }
  public InfoItemSourceFluentImpl.IngressRefNested<A> withNewIngressRef() {
    return new InfoItemSourceFluentImpl.IngressRefNestedImpl();
  }
  public InfoItemSourceFluentImpl.IngressRefNested<A> withNewIngressRefLike(IngressSelector item) {
    return new InfoItemSourceFluentImpl.IngressRefNestedImpl(item);
  }
  public InfoItemSourceFluentImpl.IngressRefNested<A> editIngressRef() {
    return withNewIngressRefLike(getIngressRef());
  }
  public InfoItemSourceFluentImpl.IngressRefNested<A> editOrNewIngressRef() {
    return withNewIngressRefLike(getIngressRef() != null ? getIngressRef(): new IngressSelectorBuilder().build());
  }
  public InfoItemSourceFluentImpl.IngressRefNested<A> editOrNewIngressRefLike(IngressSelector item) {
    return withNewIngressRefLike(getIngressRef() != null ? getIngressRef(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSecretKeyRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeySelector getSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  public SecretKeySelector buildSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  public A withSecretKeyRef(SecretKeySelector secretKeyRef) {
    _visitables.get("secretKeyRef").remove(this.secretKeyRef);
    if (secretKeyRef!=null){ this.secretKeyRef= new SecretKeySelectorBuilder(secretKeyRef); _visitables.get("secretKeyRef").add(this.secretKeyRef);} else { this.secretKeyRef = null; _visitables.get("secretKeyRef").remove(this.secretKeyRef); } return (A) this;
  }
  public Boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  public InfoItemSourceFluentImpl.SecretKeyRefNested<A> withNewSecretKeyRef() {
    return new InfoItemSourceFluentImpl.SecretKeyRefNestedImpl();
  }
  public InfoItemSourceFluentImpl.SecretKeyRefNested<A> withNewSecretKeyRefLike(SecretKeySelector item) {
    return new InfoItemSourceFluentImpl.SecretKeyRefNestedImpl(item);
  }
  public InfoItemSourceFluentImpl.SecretKeyRefNested<A> editSecretKeyRef() {
    return withNewSecretKeyRefLike(getSecretKeyRef());
  }
  public InfoItemSourceFluentImpl.SecretKeyRefNested<A> editOrNewSecretKeyRef() {
    return withNewSecretKeyRefLike(getSecretKeyRef() != null ? getSecretKeyRef(): new SecretKeySelectorBuilder().build());
  }
  public InfoItemSourceFluentImpl.SecretKeyRefNested<A> editOrNewSecretKeyRefLike(SecretKeySelector item) {
    return withNewSecretKeyRefLike(getSecretKeyRef() != null ? getSecretKeyRef(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildServiceRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceSelector getServiceRef() {
    return this.serviceRef!=null ?this.serviceRef.build():null;
  }
  public ServiceSelector buildServiceRef() {
    return this.serviceRef!=null ?this.serviceRef.build():null;
  }
  public A withServiceRef(ServiceSelector serviceRef) {
    _visitables.get("serviceRef").remove(this.serviceRef);
    if (serviceRef!=null){ this.serviceRef= new ServiceSelectorBuilder(serviceRef); _visitables.get("serviceRef").add(this.serviceRef);} else { this.serviceRef = null; _visitables.get("serviceRef").remove(this.serviceRef); } return (A) this;
  }
  public Boolean hasServiceRef() {
    return this.serviceRef != null;
  }
  public InfoItemSourceFluentImpl.ServiceRefNested<A> withNewServiceRef() {
    return new InfoItemSourceFluentImpl.ServiceRefNestedImpl();
  }
  public InfoItemSourceFluentImpl.ServiceRefNested<A> withNewServiceRefLike(ServiceSelector item) {
    return new InfoItemSourceFluentImpl.ServiceRefNestedImpl(item);
  }
  public InfoItemSourceFluentImpl.ServiceRefNested<A> editServiceRef() {
    return withNewServiceRefLike(getServiceRef());
  }
  public InfoItemSourceFluentImpl.ServiceRefNested<A> editOrNewServiceRef() {
    return withNewServiceRefLike(getServiceRef() != null ? getServiceRef(): new ServiceSelectorBuilder().build());
  }
  public InfoItemSourceFluentImpl.ServiceRefNested<A> editOrNewServiceRefLike(ServiceSelector item) {
    return withNewServiceRefLike(getServiceRef() != null ? getServiceRef(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    InfoItemSourceFluentImpl that = (InfoItemSourceFluentImpl) o;
    if (!java.util.Objects.equals(configMapKeyRef, that.configMapKeyRef)) return false;

    if (!java.util.Objects.equals(ingressRef, that.ingressRef)) return false;

    if (!java.util.Objects.equals(secretKeyRef, that.secretKeyRef)) return false;

    if (!java.util.Objects.equals(serviceRef, that.serviceRef)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configMapKeyRef,  ingressRef,  secretKeyRef,  serviceRef,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configMapKeyRef != null) { sb.append("configMapKeyRef:"); sb.append(configMapKeyRef + ","); }
    if (ingressRef != null) { sb.append("ingressRef:"); sb.append(ingressRef + ","); }
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef + ","); }
    if (serviceRef != null) { sb.append("serviceRef:"); sb.append(serviceRef + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  class ConfigMapKeyRefNestedImpl<N> extends ConfigMapKeySelectorFluentImpl<InfoItemSourceFluentImpl.ConfigMapKeyRefNested<N>> implements InfoItemSourceFluentImpl.ConfigMapKeyRefNested<N>,Nested<N>{
    ConfigMapKeyRefNestedImpl(ConfigMapKeySelector item) {
      this.builder = new ConfigMapKeySelectorBuilder(this, item);
    }
    ConfigMapKeyRefNestedImpl() {
      this.builder = new ConfigMapKeySelectorBuilder(this);
    }
    ConfigMapKeySelectorBuilder builder;
    public N and() {
      return (N) InfoItemSourceFluentImpl.this.withConfigMapKeyRef(builder.build());
    }
    public N endConfigMapKeyRef() {
      return and();
    }
    
  }
  class IngressRefNestedImpl<N> extends IngressSelectorFluentImpl<InfoItemSourceFluentImpl.IngressRefNested<N>> implements InfoItemSourceFluentImpl.IngressRefNested<N>,Nested<N>{
    IngressRefNestedImpl(IngressSelector item) {
      this.builder = new IngressSelectorBuilder(this, item);
    }
    IngressRefNestedImpl() {
      this.builder = new IngressSelectorBuilder(this);
    }
    IngressSelectorBuilder builder;
    public N and() {
      return (N) InfoItemSourceFluentImpl.this.withIngressRef(builder.build());
    }
    public N endIngressRef() {
      return and();
    }
    
  }
  class SecretKeyRefNestedImpl<N> extends SecretKeySelectorFluentImpl<InfoItemSourceFluentImpl.SecretKeyRefNested<N>> implements InfoItemSourceFluentImpl.SecretKeyRefNested<N>,Nested<N>{
    SecretKeyRefNestedImpl(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    SecretKeyRefNestedImpl() {
      this.builder = new SecretKeySelectorBuilder(this);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) InfoItemSourceFluentImpl.this.withSecretKeyRef(builder.build());
    }
    public N endSecretKeyRef() {
      return and();
    }
    
  }
  class ServiceRefNestedImpl<N> extends ServiceSelectorFluentImpl<InfoItemSourceFluentImpl.ServiceRefNested<N>> implements InfoItemSourceFluentImpl.ServiceRefNested<N>,Nested<N>{
    ServiceRefNestedImpl(ServiceSelector item) {
      this.builder = new ServiceSelectorBuilder(this, item);
    }
    ServiceRefNestedImpl() {
      this.builder = new ServiceSelectorBuilder(this);
    }
    ServiceSelectorBuilder builder;
    public N and() {
      return (N) InfoItemSourceFluentImpl.this.withServiceRef(builder.build());
    }
    public N endServiceRef() {
      return and();
    }
    
  }
  
}
